@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include item.R
 #' @include item.sub.R
 #' @include unitizer.R
@@ -122,7 +138,7 @@ setMethod("healEnvs", c("unitizerItems", "unitizer"),
           item.env <- x@base.env
         } else if (items.new.idx[[i.org]] + gaps[[i]] < 0) {
           # nocov start
-          stop("Logic Error, gap too low, contact maintainer.")
+          stop("Internal Error, gap too low, contact maintainer.")
           # nocov end
         } else {
           item.env <- y@items.new[[items.new.idx[[i.org]] + gaps[[i]]]]@env
@@ -232,7 +248,7 @@ setMethod("healEnvs", c("unitizerItems", "unitizer"),
       if(inherits(item.ref.updated, "try-error")) {
         # nocov start
         stop(
-          "Logic Error: item environment history corrupted in unknown way; ",
+          "Internal Error: item environment history corrupted in unknown way; ",
           "contact maintainer.  You can attempt to recover your `unitizer` by ",
           "using `repair_envs`."
         )
@@ -279,7 +295,7 @@ setMethod("healEnvs", c("unitizerItems", "unitizer"),
       any(!items.ref.idx %in% ref.ig.assign)
     )
       stop(
-        "Logic Error: error re-assigning ignored items to actual tests; ",
+        "Internal Error: error re-assigning ignored items to actual tests; ",
         "contact maintainer"
       )
     # nocov end
@@ -329,8 +345,8 @@ setMethod("healEnvs", c("unitizerItems", "unitizer"),
       # nocov start
       if(inherits(x, "try-error")) {
         stop(
-          "Logic Error: unable to repair reference test environments; contact ",
-          "maintainer."
+          "Internal Error: unable to repair reference test environments; ",
+          "contact maintainer."
       ) }
       # nocov end
     }
