@@ -316,64 +316,6 @@ setMethod("show", "unitizerItemTestsErrorsDiff",
     invisible(NULL)
 } )
 
-## Display Test Errors
-##
-## Also generates the object that records the diffs and the function output
-## for re-display by user.
-##
-## This is somewhat convoluted.  Better would be to compute the object that has
-## all this info, and then use the show method both when we first.
-##
-#' @rdname unitizer_s4method_doc
-
-setMethod("show", "unitizerItemTestsErrors",
-  function(object) {
-    slots <- grep("^[^.]", slotNames(object), value=TRUE)
-    slot.errs <- vapply(
-      slots, function(x) !is.null(slot(object, x)@value), logical(1L)
-    )
-    diffs <- text <- vector("list", length(slots))
-    errs <- logical(length(slots))
-    names(diffs) <- names(text) <- names(errs) <- slots
-
-    for(i in slots[slot.errs]) {
-      curr.err <- slot(object, i)
-      mismatch <- if(curr.err@compare.err) {
-        out.fun <- meta_word_msg
-        paste0("Unable to compare ", i, ": ")
-      } else {
-        out.fun <- meta_word_cat
-        paste0(cap_first(i), " mismatch: ")
-      }
-      out <- if(length(curr.err@value) < 2L) {
-        paste0(mismatch, decap_first(curr.err@value))
-      } else {
-        c(
-          mismatch,
-          as.character(
-            UL(decap_first(curr.err@value)),
-            width=getOption("width") - 2L
-        ) )
-      }
-      out.fun(out)
-      make_cont <- function(x) {
-        res <- if(identical(i, "value")) {
-          as.name(x)
-        } else call("$", as.name(toupper(x)), as.name(i))
-        call("quote", res)
-      }
-      diff <- if(object@.use.diff) diffObj(
-        curr.err@.ref, curr.err@.new, tar.banner=make_cont(".ref"),
-        cur.banner=make_cont(".new")
-      )
-      diffs[[i]] <- new(
-        "unitizerItemTestsErrorsDiff", diff=diff, txt=out, txt.alt=out,
-        err=curr.err@compare.err
-      )
-      cat("\n")
-    }
-    invisible(do.call("new", c(list("unitizerItemTestsErrorsDiffs"), diffs)))
-} )
 #' Like all.equal but Returns Empty String If Not all.equal
 #'
 #' Used as the default value comparison function since when values mismatch
