@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include class_unions.R
 
 NULL
@@ -98,7 +114,7 @@ compress_search_data <- function(x) {
   res
 }
 compress_ns_data <- function(x) {
-  vapply(x, function(y) sprintf("%s (v%s", y$name, y$version), character(1L))
+  vapply(x, function(y) sprintf("%s (v%s", y$names, y$version), character(1L))
 }
 # Search Path Management Functions
 #
@@ -666,7 +682,7 @@ get_package_data <- function() {
         try(path.package(sub("^package:(.*)", "\\1", x))) else ""
       ver <- try(getNamespaceVersion(x), silent=TRUE)
       list(
-        name=x,
+        names=x,
         lib.loc=if(!inherits(loc, "try-error")) loc else "",
         version=if(!inherits(ver, "try-error")) ver else ""
       )
